@@ -7,16 +7,13 @@ use File::Spec;
 # TODO: see where we can use P9Y::ProcessTable
 
 # ABSTRACT: Make an educated guess about the shell in use
-our $VERSION = '0.05'; # VERSION
+our $VERSION = '0.06'; # VERSION
 
 
 sub _win32_getppid
 {
-  require Win32::Process::Info;
-  Win32::Process::Info->import;
-  my $my_pid = Win32::GetCurrentProcessId();
-  my($parent_pid) = map { $_->{ParentProcessId} } grep { $_->{ProcessId} == $my_pid } Win32::Process::Info->new->GetProcInfo;
-  return $parent_pid;
+  require Win32::Getppid;
+  Win32::Getppid::getppid();
 }
 
 sub running_shell
@@ -201,7 +198,7 @@ Shell::Guess - Make an educated guess about the shell in use
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -257,7 +254,7 @@ will attempt to use that to determine the running shell.
 On UNIXy systems without a proc filesystem, Shell::Guess will use the
 ps command to determine the running shell.
 
-=item * L<Win32::Process::Info> and L<Win32::Process::List>
+=item * L<Win32::Getppid> and L<Win32::Process::List>
 
 On Windows if these modules are installed they will be used to determine
 the running shell.  This method can differentiate between PowerShell,
@@ -642,6 +639,8 @@ reliably.
 
 =item * Windows (Strawberry Perl)
 
+=item * Solaris (x86)
+
 =item * MS-DOS (djgpp)
 
 =item * OpenVMS
@@ -662,7 +661,7 @@ Patches are welcome to make other platforms work more reliably.
 
 =head1 AUTHOR
 
-author: Graham Ollis <plicease@cpan.org>
+author: Graham Ollis E<lt>plicease@cpan.orgE<gt>
 
 contributors:
 
